@@ -48,6 +48,7 @@ DLL_EXPORT const char *kto_check_retval2txt(int retval)
 DLL_EXPORT const char *kto_check_retval2iso(int retval)
 {
    switch(retval){
+      case INVALID_HANDLE: return "Ungltiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ungltiger Index fr die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt auerhalb des gltigen Bereichs";
       case IBAN_ONLY_GERMAN: return "Es werden nur deutsche IBANs untersttzt";
@@ -181,7 +182,6 @@ DLL_EXPORT const char *kto_check_retval2iso(int retval)
       case LUT2_NO_VALID_DATE: return "Der Datensatz enthlt kein Gltigkeitsdatum";
       case LUT1_SET_LOADED: return "Die Datei ist im alten LUT-Format (1.0/1.1)";
       case LUT1_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert";
-      case DTA_FILE_WITH_WARNINGS: return "In der DTAUS-Datei wurden kleinere Fehler gefunden";
       case LUT_V2_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im Format 2.0 generiert (Compilerswitch)";
       case KTO_CHECK_VALUE_REPLACED: return "ok, der Wert fr den Schlssel wurde berschrieben";
       case OK_UNTERKONTO_POSSIBLE: return "wahrscheinlich ok, die Kontonummer kann allerdings (nicht angegebene) Unterkonten enthalten";
@@ -216,6 +216,7 @@ DLL_EXPORT const char *kto_check_retval2iso(int retval)
 DLL_EXPORT const char *kto_check_retval2dos(int retval)
 {
    switch(retval){
+      case INVALID_HANDLE: return "Ungltiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ungltiger Index fr die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt auerhalb des gltigen Bereichs";
       case IBAN_ONLY_GERMAN: return "Es werden nur deutsche IBANs untersttzt";
@@ -349,7 +350,6 @@ DLL_EXPORT const char *kto_check_retval2dos(int retval)
       case LUT2_NO_VALID_DATE: return "Der Datensatz enth lt kein Gltigkeitsdatum";
       case LUT1_SET_LOADED: return "Die Datei ist im alten LUT-Format (1.0/1.1)";
       case LUT1_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert";
-      case DTA_FILE_WITH_WARNINGS: return "In der DTAUS-Datei wurden kleinere Fehler gefunden";
       case LUT_V2_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im Format 2.0 generiert (Compilerswitch)";
       case KTO_CHECK_VALUE_REPLACED: return "ok, der Wert fr den Schlssel wurde berschrieben";
       case OK_UNTERKONTO_POSSIBLE: return "wahrscheinlich ok, die Kontonummer kann allerdings (nicht angegebene) Unterkonten enthalten";
@@ -384,6 +384,7 @@ DLL_EXPORT const char *kto_check_retval2dos(int retval)
 DLL_EXPORT const char *kto_check_retval2html(int retval)
 {
    switch(retval){
+      case INVALID_HANDLE: return "Ung&uuml;ltiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ung&uuml;ltiger Index f&uuml;r die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt au&szlig;erhalb des g&uuml;ltigen Bereichs";
       case IBAN_ONLY_GERMAN: return "Es werden nur deutsche IBANs unterst&uuml;tzt";
@@ -517,7 +518,6 @@ DLL_EXPORT const char *kto_check_retval2html(int retval)
       case LUT2_NO_VALID_DATE: return "Der Datensatz enth&auml;lt kein G&uuml;ltigkeitsdatum";
       case LUT1_SET_LOADED: return "Die Datei ist im alten LUT-Format (1.0/1.1)";
       case LUT1_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert";
-      case DTA_FILE_WITH_WARNINGS: return "In der DTAUS-Datei wurden kleinere Fehler gefunden";
       case LUT_V2_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im Format 2.0 generiert (Compilerswitch)";
       case KTO_CHECK_VALUE_REPLACED: return "ok, der Wert f&uuml;r den Schl&uuml;ssel wurde &uuml;berschrieben";
       case OK_UNTERKONTO_POSSIBLE: return "wahrscheinlich ok, die Kontonummer kann allerdings (nicht angegebene) Unterkonten enthalten";
@@ -552,6 +552,7 @@ DLL_EXPORT const char *kto_check_retval2html(int retval)
 DLL_EXPORT const char *kto_check_retval2utf8(int retval)
 {
    switch(retval){
+      case INVALID_HANDLE: return "Ungültiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ungültiger Index für die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt außerhalb des gültigen Bereichs";
       case IBAN_ONLY_GERMAN: return "Es werden nur deutsche IBANs unterstützt";
@@ -685,7 +686,6 @@ DLL_EXPORT const char *kto_check_retval2utf8(int retval)
       case LUT2_NO_VALID_DATE: return "Der Datensatz enthält kein Gültigkeitsdatum";
       case LUT1_SET_LOADED: return "Die Datei ist im alten LUT-Format (1.0/1.1)";
       case LUT1_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert";
-      case DTA_FILE_WITH_WARNINGS: return "In der DTAUS-Datei wurden kleinere Fehler gefunden";
       case LUT_V2_FILE_GENERATED: return "ok, es wurde allerdings eine LUT-Datei im Format 2.0 generiert (Compilerswitch)";
       case KTO_CHECK_VALUE_REPLACED: return "ok, der Wert für den Schlüssel wurde überschrieben";
       case OK_UNTERKONTO_POSSIBLE: return "wahrscheinlich ok, die Kontonummer kann allerdings (nicht angegebene) Unterkonten enthalten";
@@ -720,6 +720,7 @@ DLL_EXPORT const char *kto_check_retval2utf8(int retval)
 DLL_EXPORT const char *kto_check_retval2txt_short(int retval)
 {
    switch(retval){
+      case INVALID_HANDLE: return "INVALID_HANDLE";
       case INVALID_BIQ_INDEX: return "INVALID_BIQ_INDEX";
       case ARRAY_INDEX_OUT_OF_RANGE: return "ARRAY_INDEX_OUT_OF_RANGE";
       case IBAN_ONLY_GERMAN: return "IBAN_ONLY_GERMAN";
@@ -853,7 +854,6 @@ DLL_EXPORT const char *kto_check_retval2txt_short(int retval)
       case LUT2_NO_VALID_DATE: return "LUT2_NO_VALID_DATE";
       case LUT1_SET_LOADED: return "LUT1_SET_LOADED";
       case LUT1_FILE_GENERATED: return "LUT1_FILE_GENERATED";
-      case DTA_FILE_WITH_WARNINGS: return "DTA_FILE_WITH_WARNINGS";
       case LUT_V2_FILE_GENERATED: return "LUT_V2_FILE_GENERATED";
       case KTO_CHECK_VALUE_REPLACED: return "KTO_CHECK_VALUE_REPLACED";
       case OK_UNTERKONTO_POSSIBLE: return "OK_UNTERKONTO_POSSIBLE";
